/* libsyslogp/src/tests/stdin_parser.c
 *
 *  (c)2009, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv3. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/

#include "syslogp.h"

#include <stdio.h>
#include <string.h>
#include <unistd.h>



struct iso8601_details
iso_details = {
    .date_prec = iso8601_prec_day,
    .time_prec = iso8601_prec_secfrac,
    .extended = 1,
};



void
test_parse(char* ln)
{
    struct syslog_msg msg;
    char isodate[40];

    syslog_parse(&msg, ln);

    printf("\n"
        "Level    : %d (%s)\n"
        "Facility : %d (%s)\n"
        "Timestamp: %s\n"
        "Hostname : '%s'\n"
        "Tag      : '%s'\n"
        "ID       : '%s'\n"
        "Message  : “%s”\n",
        msg.level, syslog_level_name(msg.level),
        msg.facility, syslog_facility_name(msg.facility),
        iso8601_print(isodate, sizeof(isodate), &msg.timestamp, &iso_details),
        msg.hostname, msg.tag, msg.id, msg.msg
    );
}



int
main(int argc, char* argv[])
{
    char* ln = 0;
    size_t lnsize = 0;
    ssize_t rd;

    if(argc == 2 && !strcmp(argv[1], "--print-summary")) {
        fputs("Parses syslog lines presented on stdin.\n", stdout);
        return 0;
    }

    while(!feof(stdin)) {
        rd = getline(&ln, &lnsize, stdin);
        if(rd == -1) return 0;
        test_parse(ln);
    }

    return 0;
}

/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
